==> freeorion_0.4.5.orig.tar.gz: src-tarball/GG/src/ClrConstants.cpp <==
/* GG is a GUI for SDL and OpenGL.
   Copyright (C) 2003-2008 T. Zachary Laine

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public License
   as published by the Free Software Foundation; either version 2.1
   of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
    
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA

   If you do not wish to comply with the terms of the LGPL please
   contact the author as other terms are available for a fee.
    
   Zach Laine
   whatwasthataddress@gmail.com */

#include <GG/ClrConstants.h>


using namespace GG;

const Clr GG::CLR_ZERO(0, 0, 0, 0);
const Clr GG::CLR_BLACK(0, 0, 0, 255);
const Clr GG::CLR_WHITE(255, 255, 255, 255);
const Clr GG::CLR_GRAY(127, 127, 127, 255);
const Clr GG::CLR_SHADOW(127, 127, 127, 127);
const Clr GG::CLR_RED(255, 0, 0, 255);
const Clr GG::CLR_GREEN(0, 255, 0, 255);
const Clr GG::CLR_BLUE(0, 0, 255, 255);
const Clr GG::CLR_CYAN(0, 255, 255, 255);
const Clr GG::CLR_YELLOW(255, 255, 0, 255);
const Clr GG::CLR_MAGENTA(255, 0, 255, 255);

==> freeorion_0.4.8.orig.tar.gz: src-tarball/GG/src/ClrConstants.cpp <==
/* GG is a GUI for SDL and OpenGL.
   Copyright (C) 2003-2008 T. Zachary Laine

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public License
   as published by the Free Software Foundation; either version 2.1
   of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
    
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA

   If you do not wish to comply with the terms of the LGPL please
   contact the author as other terms are available for a fee.
    
   Zach Laine
   whatwasthataddress@gmail.com */

#include <GG/ClrConstants.h>


using namespace GG;

const Clr GG::CLR_ZERO(0, 0, 0, 0);
const Clr GG::CLR_BLACK(0, 0, 0, 255);
const Clr GG::CLR_WHITE(255, 255, 255, 255);
const Clr GG::CLR_GRAY(127, 127, 127, 255);
const Clr GG::CLR_SHADOW(127, 127, 127, 127);
const Clr GG::CLR_RED(255, 0, 0, 255);
const Clr GG::CLR_GREEN(0, 255, 0, 255);
const Clr GG::CLR_BLUE(0, 0, 255, 255);
const Clr GG::CLR_CYAN(0, 255, 255, 255);
const Clr GG::CLR_YELLOW(255, 255, 0, 255);
const Clr GG::CLR_MAGENTA(255, 0, 255, 255);

const Clr GG::CLR_LIGHT_GRAY(192, 192, 192, 255);
const Clr GG::CLR_DARK_GRAY(64, 64, 64, 255);
const Clr GG::CLR_PINK(255, 127, 127, 255);
const Clr GG::CLR_DARK_RED(127, 0, 0, 255);
const Clr GG::CLR_OLIVE(127, 127, 0, 255);
const Clr GG::CLR_DARK_GREEN(0, 127, 0, 255);
const Clr GG::CLR_TEAL(0, 127, 127, 255);
const Clr GG::CLR_DARK_BLUE(0, 0, 127, 255);
const Clr GG::CLR_PURPLE(127, 0, 127, 255);
const Clr GG::CLR_ORANGE(255, 127, 0, 255);
